@@ -2,7 +2,6 @@ import logging
 
 from datetime import datetime
 from multiprocessing.util import Finalize
-from time import time
 
 from anyjson import deserialize, serialize
 from django.db import transaction
@@ -10,6 +9,7 @@ from django.core.exceptions import ObjectDoesNotExist
 
 from celery import schedules
 from celery.beat import Scheduler, ScheduleEntry
+from celery.utils.encoding import safe_str, safe_repr
 
 from djcelery.models import (PeriodicTask, PeriodicTasks,
                              CrontabSchedule, IntervalSchedule)
@@ -58,6 +58,7 @@ class ModelEntry(ScheduleEntry):
         self.model.total_run_count += 1
         self.model.no_changes = True
         return self.__class__(self.model)
+    __next__ = next  # for 2to3
 
     def save(self):
         # Object may not be synchronized, so only
@@ -90,11 +91,11 @@ class ModelEntry(ScheduleEntry):
                                                             defaults=fields))
 
     def __repr__(self):
-        return "<ModelEntry: %s %s(*%s, **%s) {%s}" % (self.name,
-                                                        self.task,
-                                                        self.args,
-                                                        self.kwargs,
-                                                        self.schedule)
+        return "<ModelEntry: %s %s(*%s, **%s) {%s}" % (safe_str(self.name),
+                                                       self.task,
+                                                       safe_repr(self.args),
+                                                       safe_repr(self.kwargs),
+                                                       self.schedule)
 
 
 class DatabaseScheduler(Scheduler):
@@ -106,9 +107,7 @@ class DatabaseScheduler(Scheduler):
 
     def __init__(self, *args, **kwargs):
         self._dirty = set()
-        self._last_flush = None
-        self._flush_every = 3 * 60
-        self._finalize = Finalize(self, self.flush, exitpriority=5)
+        self._finalize = Finalize(self, self.sync, exitpriority=5)
         Scheduler.__init__(self, *args, **kwargs)
         self.max_interval = 5
 
@@ -144,29 +143,21 @@ class DatabaseScheduler(Scheduler):
         self._last_timestamp = datetime.now()
         return True
 
-    def should_flush(self):
-        return not self._last_flush or \
-                    (time() - self._last_flush) > self._flush_every
-
     def reserve(self, entry):
         new_entry = Scheduler.reserve(self, entry)
-        # Need to story entry by name, because the entry may change
+        # Need to store entry by name, because the entry may change
         # in the mean time.
         self._dirty.add(new_entry.name)
-        if self.should_flush():
-            self.logger.debug("Celerybeat: Writing schedule changes...")
-            self.flush()
         return new_entry
 
     @transaction.commit_manually
-    def flush(self):
+    def sync(self):
         self.logger.debug("Writing dirty entries...")
         try:
             while self._dirty:
                 try:
                     name = self._dirty.pop()
                     self.schedule[name].save()
-                    self._last_flush = time()
                 except (KeyError, ObjectDoesNotExist):
                     pass
         except:
@@ -188,7 +179,7 @@ class DatabaseScheduler(Scheduler):
 
     def get_schedule(self):
         if self.schedule_changed():
-            self.flush()
+            self.sync()
             self.logger.debug("DatabaseScheduler: Schedule changed.")
             self._schedule = self.all_as_schedule()
             if self.logger.isEnabledFor(logging.DEBUG):
